@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'puppet-strings'
 require 'puppet-strings/json'
 require 'puppet-strings/yard'
@@ -68,7 +70,7 @@ module PuppetStrings::Markdown
 
     # @return [String] top-level name
     def name
-      @registry[:name].to_s unless @registry[:name].nil?
+      @registry[:name]&.to_s
     end
 
     # @return [String] 'Overview' text (untagged text)
@@ -170,6 +172,8 @@ module PuppetStrings::Markdown
     end
 
     def word_wrap(text, line_width: 120, break_sequence: "\n")
+      return unless text
+
       text.split("\n").collect! do |line|
         line.length > line_width ? line.gsub(/(.{1,#{line_width}})(\s+|$)/, "\\1#{break_sequence}").strip : line
       end * break_sequence
@@ -177,8 +181,12 @@ module PuppetStrings::Markdown
 
     # @return [String] full markdown rendering of a component
     def render(template)
-      file = File.join(File.dirname(__FILE__),"templates/#{template}")
-      ERB.new(File.read(file), nil, '-').result(binding)
+      begin
+        file = File.join(File.dirname(__FILE__),"templates/#{template}")
+        ERB.new(File.read(file), nil, '-').result(binding)
+      rescue StandardError => e
+        fail "Processing #{@registry[:file]}:#{@registry[:line]} with #{file} => #{e}"
+      end
     end
 
     private
