@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'data_type'
 
 module PuppetStrings::Markdown
@@ -22,7 +24,7 @@ module PuppetStrings::Markdown
     def self.render
       final = in_dtypes.length > 0 ? "## Data types\n\n" : ""
       in_dtypes.each do |type|
-        final << type.render unless type.private?
+        final += type.render unless type.private?
       end
       final
     end
