@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'puppet-strings/yard/code_objects/group'
 require 'puppet-strings/yard/util'
 
@@ -146,11 +148,12 @@ class PuppetStrings::Yard::CodeObjects::Type < PuppetStrings::Yard::CodeObjects:
   end
 
   def parameters
+    @parameters ||= []  # guard against not filled parameters
     # just return params if there are no providers
     return @parameters if providers.empty?
 
     # return existing params if we have already added provider
-    return @parameters if @parameters.any? { |p| p.name == 'provider' }
+    return @parameters if @parameters&.any? { |p| p.name == 'provider' }
 
     provider_param = Parameter.new(
       'provider',
@@ -158,6 +161,7 @@ class PuppetStrings::Yard::CodeObjects::Type < PuppetStrings::Yard::CodeObjects:
       "to specify this --- Puppet will usually discover the appropriate provider for your platform."
     )
 
+    @parameters ||= []
     @parameters << provider_param
   end
 
@@ -167,6 +171,7 @@ class PuppetStrings::Yard::CodeObjects::Type < PuppetStrings::Yard::CodeObjects:
   def providers
     providers = YARD::Registry.all("puppet_providers_#{name}".intern)
     return providers if providers.empty?
+
     providers.first.children
   end
 
