@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'puppet-strings/yard/handlers/helpers'
 require 'puppet-strings/yard/handlers/ruby/type_base'
 require 'puppet-strings/yard/code_objects'
@@ -6,7 +8,7 @@ require 'puppet-strings/yard/util'
 # Implements the handler for Puppet resource types written in Ruby.
 class PuppetStrings::Yard::Handlers::Ruby::TypeHandler < PuppetStrings::Yard::Handlers::Ruby::TypeBase
   # The default docstring when ensurable is used without given a docstring.
-  DEFAULT_ENSURABLE_DOCSTRING = 'The basic property that the resource should be in.'.freeze
+  DEFAULT_ENSURABLE_DOCSTRING = 'The basic property that the resource should be in.'
 
   namespace_only
   handles method_call(:newtype)
@@ -14,6 +16,7 @@ class PuppetStrings::Yard::Handlers::Ruby::TypeHandler < PuppetStrings::Yard::Ha
   process do
     # Only accept calls to Puppet::Type
     return unless statement.count > 1
+
     module_name = statement[0].source
     return unless module_name == 'Puppet::Type' || module_name == 'Type'
 
@@ -40,6 +43,7 @@ class PuppetStrings::Yard::Handlers::Ruby::TypeHandler < PuppetStrings::Yard::Ha
     # Traverse the block looking for properties/parameters/features
     block = statement.block
     return unless block && block.count >= 2
+
     block[1].children.each do |node|
       next unless node.is_a?(YARD::Parser::Ruby::MethodCallNode) &&
                   node.method_name
@@ -50,24 +54,31 @@ class PuppetStrings::Yard::Handlers::Ruby::TypeHandler < PuppetStrings::Yard::Ha
       if method_name == 'newproperty'
         # Add a property to the object
         next unless parameters.count >= 1
+
         name = node_as_string(parameters[0])
         next unless name
+
         object.add_property(create_property(name, node))
       elsif method_name == 'newparam'
         # Add a parameter to the object
         next unless parameters.count >= 1
+
         name = node_as_string(parameters[0])
         next unless name
+
         object.add_parameter(create_parameter(name, node))
       elsif method_name == 'newcheck'
         # Add a check to the object
         next unless parameters.count >= 1
+
         name = node_as_string(parameters[0])
         next unless name
+
         object.add_check(create_check(name, node))
       elsif method_name == 'feature'
         # Add a feature to the object
         next unless parameters.count >= 2
+
         name = node_as_string(parameters[0])
         next unless name
 
