@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 all
 
 # Update line length to 120 chars.
@@ -8,3 +10,6 @@ exclude_rule 'MD024'
 
 # Allow trailing punctuation in headings.
 exclude_rule 'MD026'
+
+# Allow html tags
+exclude_rule 'MD033'
\ No newline at end of file
